mysql.util.misc

Package mysql :: Package util :: Module misc |
[hide private]
[frames] | no frames]

# Module misc

Miscellaneous utility functions.

Functions | [hide private]
`` | big_str_to_host_int(...) Convert a string in big-endian format into an integer.

Variables | [hide private]
`` | __version__ = `'$Revision: 1.6 $'`

Function Details | [hide private]

### big_str_to_host_int(...) |
Convert a string in big-endian format into an integer. Parameters: `value` - A binary string in big-endian format. Must be less than or equal to 8 bytes in length. Returns: Returns an integer.

Variables Details | [hide private]

    ### __version__ Value:
        '$Revision: 1.6 $'